@@ -114,6 +114,12 @@
 #' Institute of Computer Science of the Czech Academy of Sciences \cr
 #' \email{martinkova@@cs.cas.cz} \cr
 #'
+#' @references
+#' Agresti, A. (2010). Analysis of ordinal categorical data. Second edition. John Wiley & Sons.
+#'
+#' Hladka, A. & Martinkova, P. (2020). difNLR: Generalized logistic regression models for DIF and DDF detection.
+#' The R journal, 12(1), 300--323, \doi{10.32614/RJ-2020-014}.
+#'
 #' @seealso
 #' \code{\link[difNLR]{plot.ddfMLR}} for graphical representation of item characteristic curves. \cr
 #' \code{\link[difNLR]{coef.ddfMLR}} for extraction of item parameters with their standard errors. \cr
@@ -266,6 +272,8 @@ ddfMLR <- function(Data, group, focal.name, key, type = "both", match = "zscore"
 
     GROUP <- df[, "GROUP"]
     DATA <- data.frame(df[, !(colnames(df) %in% c("GROUP", "match"))])
+    DATA[] <- lapply(DATA[], as.factor)
+    DATA[] <- lapply(DATA[], droplevels)
 
     if (length(match) > 1) {
       match <- df[, "match"]
